/*
 * Copyright (C) 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.providers.media.util;

import android.icu.text.MessageFormat;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Objects;

import android.content.res.Resources;

import androidx.annotation.Nullable;

public class StringUtils {

  /**
   * Returns the formatted ICU format string corresponding to the provided resource ID and count
   * number of entities in the plural string.
   */
  public static String getICUFormatString(Resources resources, int count, int resourceID) {
    MessageFormat msgFormat = new MessageFormat(
        resources.getString(resourceID),
        Locale.getDefault());
    Map<String, Object> arguments = new HashMap<>();
    arguments.put("count", count);
    return msgFormat.format(arguments);
  }


  /**
   * Variant of {@link String#startsWith(String)} but which tests with
   * case-insensitivity.
   */
  public static boolean startsWithIgnoreCase(@Nullable String target, @Nullable String other) {
    if (target == null || other == null) return false;
    if (other.length() > target.length()) return false;
    return target.regionMatches(true, 0, other, 0, other.length());
  }

  /**
   * Variant of {@link Objects#equal(Object, Object)} but which tests with
   * case-insensitivity.
   */
  public static boolean equalIgnoreCase(@Nullable String a, @Nullable String b) {
      return (a != null) && a.equalsIgnoreCase(b);
  }
}
